==> tax-device-contract-model-1.1-20190715.112923-33-sources.jar: com/xforceplus/micro/tax/device/contract/model/LicenseKeyRequest.java <==
package com.xforceplus.micro.tax.device.contract.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.micro.tax.device.contract.model.RequestHead;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import java.io.Serializable;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * LicenseKeyRequest
 */

@JsonInclude(NON_NULL)
public class LicenseKeyRequest implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("head")
  private RequestHead head = null;

  @JsonProperty("unionId")
  private String unionId = null;

  @JsonProperty("deviceUn")
  private String deviceUn = null;

  @JsonIgnore
  public LicenseKeyRequest head(RequestHead head) {
    this.head = head;
    return this;
  }

   /**
   * 标准请求头信息
   * @return head
  **/

  @Valid

  @ApiModelProperty(value = "标准请求头信息")
  public RequestHead getHead() {
    return head;
  }

  public void setHead(RequestHead head) {
    this.head = head;
  }

  @JsonIgnore
  public LicenseKeyRequest unionId(String unionId) {
    this.unionId = unionId;
    return this;
  }

   /**
   * 终端unionId（已废弃，用deviceUn代替）
   * @return unionId
  **/


  @ApiModelProperty(value = "终端unionId（已废弃，用deviceUn代替）")
  public String getUnionId() {
    return unionId;
  }

  public void setUnionId(String unionId) {
    this.unionId = unionId;
  }

  @JsonIgnore
  public LicenseKeyRequest deviceUn(String deviceUn) {
    this.deviceUn = deviceUn;
    return this;
  }

   /**
   * 设备唯一码
   * @return deviceUn
  **/


  @ApiModelProperty(value = "设备唯一码")
  public String getDeviceUn() {
    return deviceUn;
  }

  public void setDeviceUn(String deviceUn) {
    this.deviceUn = deviceUn;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    LicenseKeyRequest licenseKeyRequest = (LicenseKeyRequest) o;
    return Objects.equals(this.head, licenseKeyRequest.head) &&
        Objects.equals(this.unionId, licenseKeyRequest.unionId) &&
        Objects.equals(this.deviceUn, licenseKeyRequest.deviceUn);
  }

  @Override
  public int hashCode() {
    return Objects.hash(head, unionId, deviceUn);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class LicenseKeyRequest {\n");
    
    sb.append("    head: ").append(toIndentedString(head)).append("\n");
    sb.append("    unionId: ").append(toIndentedString(unionId)).append("\n");
    sb.append("    deviceUn: ").append(toIndentedString(deviceUn)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> tax-device-contract-model-1.7-20240613.095407-45-sources.jar: com/xforceplus/micro/tax/device/contract/model/LicenseKeyRequest.java <==
package com.xforceplus.micro.tax.device.contract.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.micro.tax.device.contract.model.RequestHead;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import java.io.Serializable;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * LicenseKeyRequest
 */

@JsonInclude(NON_NULL)
public class LicenseKeyRequest implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("head")
  private RequestHead head = null;

  @JsonProperty("unionId")
  private String unionId = null;

  @JsonProperty("terminalUn")
  private String terminalUn = null;

  @JsonIgnore
  public LicenseKeyRequest head(RequestHead head) {
    this.head = head;
    return this;
  }

   /**
   * 标准请求头信息
   * @return head
  **/

  @Valid

  @ApiModelProperty(value = "标准请求头信息")
  public RequestHead getHead() {
    return head;
  }

  public void setHead(RequestHead head) {
    this.head = head;
  }

  @JsonIgnore
  public LicenseKeyRequest unionId(String unionId) {
    this.unionId = unionId;
    return this;
  }

   /**
   * 终端unionId（已废弃，用terminalUn代替）
   * @return unionId
  **/


  @ApiModelProperty(value = "终端unionId（已废弃，用terminalUn代替）")
  public String getUnionId() {
    return unionId;
  }

  public void setUnionId(String unionId) {
    this.unionId = unionId;
  }

  @JsonIgnore
  public LicenseKeyRequest terminalUn(String terminalUn) {
    this.terminalUn = terminalUn;
    return this;
  }

   /**
   * 终端唯一码
   * @return terminalUn
  **/


  @ApiModelProperty(value = "终端唯一码")
  public String getTerminalUn() {
    return terminalUn;
  }

  public void setTerminalUn(String terminalUn) {
    this.terminalUn = terminalUn;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    LicenseKeyRequest licenseKeyRequest = (LicenseKeyRequest) o;
    return Objects.equals(this.head, licenseKeyRequest.head) &&
        Objects.equals(this.unionId, licenseKeyRequest.unionId) &&
        Objects.equals(this.terminalUn, licenseKeyRequest.terminalUn);
  }

  @Override
  public int hashCode() {
    return Objects.hash(head, unionId, terminalUn);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class LicenseKeyRequest {\n");
    
    sb.append("    head: ").append(toIndentedString(head)).append("\n");
    sb.append("    unionId: ").append(toIndentedString(unionId)).append("\n");
    sb.append("    terminalUn: ").append(toIndentedString(terminalUn)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
